:tocdepth: 2

Version history
===============


Abjad 2.16
----------

Full 2.16 version history is forthcoming.

Older versions
--------------

..  toctree::
    :maxdepth: 1

    version_2_15
    version_2_14
    version_2_13
    version_2_12
    version_2_11
    version_2_10
    version_2_9
    version_2_8
    version_2_7
    version_2_6
    version_2_5
    version_2_4
    version_2_3
    version_2_2
    version_2_1
    version_2_0